@@ -460,7 +460,7 @@
 #define PCI_CHIP_SUMO2_9645 0x9645
 #define PCI_CHIP_SUMO_9647 0x9647
 #define PCI_CHIP_SUMO_9648 0x9648
-#define PCI_CHIP_SUMO_9649 0x9649
+#define PCI_CHIP_SUMO2_9649 0x9649
 #define PCI_CHIP_SUMO_964A 0x964A
 #define PCI_CHIP_SUMO_964B 0x964B
 #define PCI_CHIP_SUMO_964C 0x964C
@@ -603,6 +603,10 @@
 #define PCI_CHIP_ARUBA_9908 0x9908
 #define PCI_CHIP_ARUBA_9909 0x9909
 #define PCI_CHIP_ARUBA_990A 0x990A
+#define PCI_CHIP_ARUBA_990B 0x990B
+#define PCI_CHIP_ARUBA_990C 0x990C
+#define PCI_CHIP_ARUBA_990D 0x990D
+#define PCI_CHIP_ARUBA_990E 0x990E
 #define PCI_CHIP_ARUBA_990F 0x990F
 #define PCI_CHIP_ARUBA_9910 0x9910
 #define PCI_CHIP_ARUBA_9913 0x9913
@@ -614,6 +618,15 @@
 #define PCI_CHIP_ARUBA_9992 0x9992
 #define PCI_CHIP_ARUBA_9993 0x9993
 #define PCI_CHIP_ARUBA_9994 0x9994
+#define PCI_CHIP_ARUBA_9995 0x9995
+#define PCI_CHIP_ARUBA_9996 0x9996
+#define PCI_CHIP_ARUBA_9997 0x9997
+#define PCI_CHIP_ARUBA_9998 0x9998
+#define PCI_CHIP_ARUBA_9999 0x9999
+#define PCI_CHIP_ARUBA_999A 0x999A
+#define PCI_CHIP_ARUBA_999B 0x999B
+#define PCI_CHIP_ARUBA_999C 0x999C
+#define PCI_CHIP_ARUBA_999D 0x999D
 #define PCI_CHIP_ARUBA_99A0 0x99A0
 #define PCI_CHIP_ARUBA_99A2 0x99A2
 #define PCI_CHIP_ARUBA_99A4 0x99A4
@@ -627,6 +640,7 @@
 #define PCI_CHIP_TAHITI_6798 0x6798
 #define PCI_CHIP_TAHITI_6799 0x6799
 #define PCI_CHIP_TAHITI_679A 0x679A
+#define PCI_CHIP_TAHITI_679B 0x679B
 #define PCI_CHIP_TAHITI_679E 0x679E
 #define PCI_CHIP_TAHITI_679F 0x679F
 #define PCI_CHIP_PITCAIRN_6800 0x6800
@@ -644,6 +658,7 @@
 #define PCI_CHIP_PITCAIRN_684C 0x684C
 #define PCI_CHIP_VERDE_6820 0x6820
 #define PCI_CHIP_VERDE_6821 0x6821
+#define PCI_CHIP_VERDE_6822 0x6822
 #define PCI_CHIP_VERDE_6823 0x6823
 #define PCI_CHIP_VERDE_6824 0x6824
 #define PCI_CHIP_VERDE_6825 0x6825
@@ -651,14 +666,92 @@
 #define PCI_CHIP_VERDE_6827 0x6827
 #define PCI_CHIP_VERDE_6828 0x6828
 #define PCI_CHIP_VERDE_6829 0x6829
+#define PCI_CHIP_VERDE_682A 0x682A
 #define PCI_CHIP_VERDE_682B 0x682B
 #define PCI_CHIP_VERDE_682D 0x682D
 #define PCI_CHIP_VERDE_682F 0x682F
 #define PCI_CHIP_VERDE_6830 0x6830
 #define PCI_CHIP_VERDE_6831 0x6831
+#define PCI_CHIP_VERDE_6835 0x6835
 #define PCI_CHIP_VERDE_6837 0x6837
 #define PCI_CHIP_VERDE_6838 0x6838
 #define PCI_CHIP_VERDE_6839 0x6839
 #define PCI_CHIP_VERDE_683B 0x683B
 #define PCI_CHIP_VERDE_683D 0x683D
 #define PCI_CHIP_VERDE_683F 0x683F
+#define PCI_CHIP_OLAND_6600 0x6600
+#define PCI_CHIP_OLAND_6601 0x6601
+#define PCI_CHIP_OLAND_6602 0x6602
+#define PCI_CHIP_OLAND_6603 0x6603
+#define PCI_CHIP_OLAND_6606 0x6606
+#define PCI_CHIP_OLAND_6607 0x6607
+#define PCI_CHIP_OLAND_6610 0x6610
+#define PCI_CHIP_OLAND_6611 0x6611
+#define PCI_CHIP_OLAND_6613 0x6613
+#define PCI_CHIP_OLAND_6620 0x6620
+#define PCI_CHIP_OLAND_6621 0x6621
+#define PCI_CHIP_OLAND_6623 0x6623
+#define PCI_CHIP_OLAND_6631 0x6631
+#define PCI_CHIP_HAINAN_6660 0x6660
+#define PCI_CHIP_HAINAN_6663 0x6663
+#define PCI_CHIP_HAINAN_6664 0x6664
+#define PCI_CHIP_HAINAN_6665 0x6665
+#define PCI_CHIP_HAINAN_6667 0x6667
+#define PCI_CHIP_HAINAN_666F 0x666F
+#define PCI_CHIP_BONAIRE_6640 0x6640
+#define PCI_CHIP_BONAIRE_6641 0x6641
+#define PCI_CHIP_BONAIRE_6649 0x6649
+#define PCI_CHIP_BONAIRE_6650 0x6650
+#define PCI_CHIP_BONAIRE_6651 0x6651
+#define PCI_CHIP_BONAIRE_6658 0x6658
+#define PCI_CHIP_BONAIRE_665C 0x665C
+#define PCI_CHIP_BONAIRE_665D 0x665D
+#define PCI_CHIP_KABINI_9830 0x9830
+#define PCI_CHIP_KABINI_9831 0x9831
+#define PCI_CHIP_KABINI_9832 0x9832
+#define PCI_CHIP_KABINI_9833 0x9833
+#define PCI_CHIP_KABINI_9834 0x9834
+#define PCI_CHIP_KABINI_9835 0x9835
+#define PCI_CHIP_KABINI_9836 0x9836
+#define PCI_CHIP_KABINI_9837 0x9837
+#define PCI_CHIP_KABINI_9838 0x9838
+#define PCI_CHIP_KABINI_9839 0x9839
+#define PCI_CHIP_KABINI_983A 0x983A
+#define PCI_CHIP_KABINI_983B 0x983B
+#define PCI_CHIP_KABINI_983C 0x983C
+#define PCI_CHIP_KABINI_983D 0x983D
+#define PCI_CHIP_KABINI_983E 0x983E
+#define PCI_CHIP_KABINI_983F 0x983F
+#define PCI_CHIP_KAVERI_1304 0x1304
+#define PCI_CHIP_KAVERI_1305 0x1305
+#define PCI_CHIP_KAVERI_1306 0x1306
+#define PCI_CHIP_KAVERI_1307 0x1307
+#define PCI_CHIP_KAVERI_1309 0x1309
+#define PCI_CHIP_KAVERI_130A 0x130A
+#define PCI_CHIP_KAVERI_130B 0x130B
+#define PCI_CHIP_KAVERI_130C 0x130C
+#define PCI_CHIP_KAVERI_130D 0x130D
+#define PCI_CHIP_KAVERI_130E 0x130E
+#define PCI_CHIP_KAVERI_130F 0x130F
+#define PCI_CHIP_KAVERI_1310 0x1310
+#define PCI_CHIP_KAVERI_1311 0x1311
+#define PCI_CHIP_KAVERI_1312 0x1312
+#define PCI_CHIP_KAVERI_1313 0x1313
+#define PCI_CHIP_KAVERI_1315 0x1315
+#define PCI_CHIP_KAVERI_1316 0x1316
+#define PCI_CHIP_KAVERI_1317 0x1317
+#define PCI_CHIP_KAVERI_131B 0x131B
+#define PCI_CHIP_KAVERI_131C 0x131C
+#define PCI_CHIP_KAVERI_131D 0x131D
+#define PCI_CHIP_HAWAII_67A0 0x67A0
+#define PCI_CHIP_HAWAII_67A1 0x67A1
+#define PCI_CHIP_HAWAII_67A2 0x67A2
+#define PCI_CHIP_HAWAII_67A8 0x67A8
+#define PCI_CHIP_HAWAII_67A9 0x67A9
+#define PCI_CHIP_HAWAII_67AA 0x67AA
+#define PCI_CHIP_HAWAII_67B0 0x67B0
+#define PCI_CHIP_HAWAII_67B1 0x67B1
+#define PCI_CHIP_HAWAII_67B8 0x67B8
+#define PCI_CHIP_HAWAII_67B9 0x67B9
+#define PCI_CHIP_HAWAII_67BA 0x67BA
+#define PCI_CHIP_HAWAII_67BE 0x67BE
