@@ -134,18 +134,11 @@
 # define __FUNCTION__ __func__		/* C99 */
 #endif
 
-#ifndef HAVE_XF86MODEBANDWIDTH
-extern unsigned int xf86ModeBandwidth(DisplayModePtr mode, int depth);
-#define MODE_BANDWIDTH MODE_BAD
-#endif
-
 typedef enum {
     OPTION_NOACCEL,
     OPTION_SW_CURSOR,
     OPTION_PAGE_FLIP,
-    OPTION_ACCEL_DFS,
     OPTION_EXA_PIXMAPS,
-    OPTION_IGNORE_EDID,
     OPTION_COLOR_TILING,
     OPTION_COLOR_TILING_2D,
 #ifdef RENDER
@@ -153,8 +146,6 @@ typedef enum {
     OPTION_SUBPIXEL_ORDER,
 #endif
     OPTION_ACCELMETHOD,
-    OPTION_DRI,
-    OPTION_TVSTD,
     OPTION_EXA_VSYNC,
     OPTION_ZAPHOD_HEADS,
     OPTION_SWAPBUFFERS_WAIT
@@ -221,11 +212,11 @@ typedef enum {
 	(info->ChipFamily == CHIP_FAMILY_RV560)  ||  \
 	(info->ChipFamily == CHIP_FAMILY_RV570))
 
+/* RS6xx, RS740 are technically R4xx as well, but the
+ * clipping hardware seems to follow the r3xx restrictions
+ */
 #define IS_R400_3D ((info->ChipFamily == CHIP_FAMILY_R420)  ||  \
-	(info->ChipFamily == CHIP_FAMILY_RV410) ||  \
-	(info->ChipFamily == CHIP_FAMILY_RS690) ||  \
-	(info->ChipFamily == CHIP_FAMILY_RS600) ||  \
-	(info->ChipFamily == CHIP_FAMILY_RS740))
+	(info->ChipFamily == CHIP_FAMILY_RV410))
 
 #define IS_R300_3D ((info->ChipFamily == CHIP_FAMILY_R300)  ||  \
 	(info->ChipFamily == CHIP_FAMILY_RV350) ||  \
@@ -244,6 +235,12 @@ typedef enum {
 	(info->ChipFamily == CHIP_FAMILY_RS300) || \
 	(info->ChipFamily == CHIP_FAMILY_R200))
 
+#define CURSOR_WIDTH	64
+#define CURSOR_HEIGHT	64
+
+#define CURSOR_WIDTH_CIK	128
+#define CURSOR_HEIGHT_CIK	128
+
 struct radeon_exa_pixmap_priv {
     struct radeon_bo *bo;
     uint32_t tiling_flags;
@@ -408,9 +405,6 @@ struct radeon_accel_state {
 typedef struct {
     EntityInfoPtr     pEnt;
     pciVideoPtr       PciInfo;
-#ifndef XSERVER_LIBPCIACCESS
-    PCITAG            PciTag;
-#endif
     int               Chipset;
     RADEONChipFamily  ChipFamily;
 
@@ -437,6 +431,7 @@ typedef struct {
     Bool	      exa_pixmaps;
     Bool              exa_force_create;
     XF86ModReqInfo    exaReq;
+    Bool              is_fast_fb; /* use direct mapping for fast fb access */
 
     unsigned int xv_max_width;
     unsigned int xv_max_height;
@@ -465,6 +460,7 @@ typedef struct {
     uint64_t vram_size;
     uint64_t gart_size;
     drmmode_rec drmmode;
+    Bool drmmode_inited;
     /* r6xx+ tile config */
     Bool have_tiling_info;
     uint32_t tile_config;
@@ -483,6 +479,10 @@ typedef struct {
 
     /* Perform vsync'ed SwapBuffers? */
     Bool swapBuffersWait;
+
+    /* cursor size */
+    int cursor_w;
+    int cursor_h;
 } RADEONInfoRec, *RADEONInfoPtr;
 
 /* radeon_accel.c */
@@ -497,9 +497,6 @@ extern void RADEONWaitForVLine(ScrnInfoPtr pScrn, PixmapPtr pPix,
 			       xf86CrtcPtr crtc, int start, int stop);
 
 
-/* radeon_driver.c */
-extern RADEONEntPtr RADEONEntPriv(ScrnInfoPtr pScrn);
-
 /* radeon_exa.c */
 extern unsigned eg_tile_split(unsigned tile_split);
 extern Bool radeon_transform_is_affine_or_scaled(PictTransformPtr t);
@@ -520,13 +517,17 @@ extern void RADEONInitVideo(ScreenPtr pScreen);
 extern void RADEONResetVideo(ScrnInfoPtr pScrn);
 extern Bool radeon_load_bicubic_texture(ScrnInfoPtr pScrn);
 extern xf86CrtcPtr radeon_pick_best_crtc(ScrnInfoPtr pScrn,
+					 Bool consider_disabled,
 					 int x1, int x2, int y1, int y2);
 
 extern void radeon_cs_flush_indirect(ScrnInfoPtr pScrn);
 extern void radeon_ddx_cs_start(ScrnInfoPtr pScrn,
 				int num, const char *file,
 				const char *func, int line);
-void radeon_kms_update_vram_limit(ScrnInfoPtr pScrn, int new_fb_size);
+void radeon_kms_update_vram_limit(ScrnInfoPtr pScrn, uint32_t new_fb_size);
+extern RADEONEntPtr RADEONEntPriv(ScrnInfoPtr pScrn);
+
+drmVBlankSeqType radeon_populate_vbl_request_type(xf86CrtcPtr crtc);
 
 #if XF86_CRTC_VERSION >= 5
 #define RADEON_PIXMAP_SHARING 1
@@ -573,16 +574,20 @@ static inline void radeon_set_pixmap_bo(PixmapPtr pPix, struct radeon_bo *bo)
 	    if (priv->bo)
 		radeon_bo_unref(priv->bo);
 
-	    free(priv);
-	    priv = NULL;
+	    if (!bo) {
+		free(priv);
+		priv = NULL;
+	    }
 	}
 
 	if (bo) {
 	    uint32_t pitch;
 
-	    priv = calloc(1, sizeof (struct radeon_pixmap));
-	    if (priv == NULL)
-		goto out;
+	    if (!priv) {
+		priv = calloc(1, sizeof (struct radeon_pixmap));
+		if (!priv)
+		    goto out;
+	    }
 
 	    radeon_bo_ref(bo);
 	    priv->bo = bo;
@@ -786,6 +791,7 @@ enum {
     RADEON_CREATE_PIXMAP_TILING_MICRO = 0x20000000,
     RADEON_CREATE_PIXMAP_DEPTH = 0x40000000, /* for r200 */
     RADEON_CREATE_PIXMAP_SZBUFFER = 0x80000000, /* for eg */
+    RADEON_CREATE_PIXMAP_TILING_MICRO_SQUARE = 0x8000000,
 };
 
 
